@@ -113,6 +113,11 @@ class Script(default.Script):
             orca.setLocusOfFocus(event, event.source)
             return
 
+        # https://bugzilla.gnome.org/show_bug.cgi?id=748311
+        if role == pyatspi.ROLE_TERMINAL:
+            orca.setLocusOfFocus(event, event.source)
+            return
+
         # https://bugzilla.gnome.org/show_bug.cgi?id=720987
         if role == pyatspi.ROLE_TABLE_COLUMN_HEADER:
             orca.setLocusOfFocus(event, event.source)
